<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @link       https://profiles.wordpress.org/dots
 * @since      1.0.0
 * @package    Gdpr_Compliance_Toolkit
 * @subpackage Gdpr_Compliance_Toolkit/includes
 * @author     Multidots <inquiry@multidots.in>
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Gdpr_Compliance_Toolkit {

	const GDPRCT_VERSION = '1.0.0';
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Gdpr_Compliance_Toolkit_Loader $loader Maintains and registers all hooks for the plugin.
	 */
	protected $loader;
	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string $plugin_name The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;
	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string $version The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'GDPRCT_PLUGIN_NAME_VERSION' ) ) {
			$this->version = GDPRCT_PLUGIN_NAME_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'gdpr-compliance-toolkit';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Gdpr_Compliance_Toolkit_Loader. Orchestrates the hooks of the plugin.
	 * - Gdpr_Compliance_Toolkit_i18n. Defines internationalization functionality.
	 * - Gdpr_Compliance_Toolkit_Admin. Defines all hooks for the admin area.
	 * - Gdpr_Compliance_Toolkit_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gdpr-compliance-toolkit-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-gdpr-compliance-toolkit-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-gdpr-compliance-toolkit-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-gdpr-compliance-toolkit-public.php';

		$this->loader = new Gdpr_Compliance_Toolkit_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Gdpr_Compliance_Toolkit_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Gdpr_Compliance_Toolkit_i18n();
		$plugin_i18n->set_domain( $this->get_plugin_name() );
		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Gdpr_Compliance_Toolkit_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'gdprct_dot_store_menu' );
		$this->loader->add_action( 'admin_init', $plugin_admin, 'gdprct_welcome_screen_do_activation_redirect' );
		$this->loader->add_action( 'admin_head', $plugin_admin, 'gdprct_remove_admin_submenus' );

		$this->loader->add_action( 'wp_ajax_gdprct_delete_single_gdpr_using_button', $plugin_admin, 'gdprct_delete_single_gdpr_using_button' );
		$this->loader->add_action( 'wp_ajax_nopriv_gdprct_delete_single_gdpr_using_button', $plugin_admin, 'gdprct_delete_single_gdpr_using_button' );

		$this->loader->add_action( 'wp_ajax_gdprct_delete_selected_gdpr_using_checkbox', $plugin_admin, 'gdprct_delete_selected_gdpr_using_checkbox' );
		$this->loader->add_action( 'wp_ajax_nopriv_gdprct_delete_selected_gdpr_using_checkbox', $plugin_admin, 'gdprct_delete_selected_gdpr_using_checkbox' );

		$this->loader->add_action( 'wp_ajax_gdprct_send_mail_selected_gdpr_using_checkbox', $plugin_admin, 'gdprct_send_mail_selected_gdpr_using_checkbox' );
		$this->loader->add_action( 'wp_ajax_nopriv_gdprct_send_mail_selected_gdpr_using_checkbox', $plugin_admin, 'gdprct_send_mail_selected_gdpr_using_checkbox' );

		$this->loader->add_action( 'wp_ajax_gdprct_send_mail_single_gdpr_using_button', $plugin_admin, 'gdprct_send_mail_single_gdpr_using_button' );
		$this->loader->add_action( 'wp_ajax_nopriv_gdprct_send_mail_single_gdpr_using_button', $plugin_admin, 'gdprct_send_mail_single_gdpr_using_button' );

		$this->loader->add_action( 'wp_ajax_gdprct_get_admin_list_with_pagination', $plugin_admin, 'gdprct_get_admin_list_with_pagination' );
		$this->loader->add_action( 'wp_ajax_nopriv_gdprct_get_admin_list_with_pagination', $plugin_admin, 'gdprct_get_admin_list_with_pagination' );
		$this->loader->add_action( 'plugin_row_meta', $plugin_admin, 'check_page_visit_plugin_row_meta',10,2 );
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Gdpr_Compliance_Toolkit_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

		$get_gdpr_compilation_toolkit = json_decode( get_option( 'gdpr_compilation_toolkit' ) );

		if ( isset( $get_gdpr_compilation_toolkit->woo_integration->on ) ) {
			$woo_integration_on = $get_gdpr_compilation_toolkit->woo_integration->on;
		} else {
			$woo_integration_on = '';
		}
		if ( $woo_integration_on == 'on' ) {
			$this->loader->add_filter( 'woocommerce_locate_template', $plugin_public, 'gdprct_locate_template_conditions', 1, 3 );

			$this->loader->add_action( 'woocommerce_review_order_before_submit', $plugin_public, 'gdprct_add_field', 999 );
			$this->loader->add_action( 'woocommerce_checkout_process', $plugin_public, 'gdprct_check_post' );

			$this->loader->add_action( 'woocommerce_checkout_update_order_meta', $plugin_public, 'gdprct_add_accepted_date_to_order_meta' );
			$this->loader->add_action( 'woocommerce_admin_order_data_after_order_details', $plugin_public, 'gdprct_display_accepted_date_in_order_meta' );

			$this->loader->add_action( 'init', $plugin_public, 'gdprct_add_custom_my_gdpr_data_endpoint' );
			$this->loader->add_filter( 'query_vars', $plugin_public, 'gdprct_my_gdpr_data_query_vars', 0 );
			$this->loader->add_filter( 'woocommerce_account_menu_items', $plugin_public, 'gdprct_add_my_gdpr_data_link_my_account' );
			$this->loader->add_action( 'woocommerce_account_my-gdpr-data_endpoint', $plugin_public, 'gdprct_my_gdpr_data_content' );
		}
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Gdpr_Compliance_Toolkit_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}
}