<?php

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @link       https://profiles.wordpress.org/dots
 * @since      1.0.0
 * @package    Gdpr_Compliance_Toolkit
 * @subpackage Gdpr_Compliance_Toolkit/public
 * @author     Multidots <inquiry@multidots.in>
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Gdpr_Compliance_Toolkit_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string $plugin_name The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string $version The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 *
	 * @param      string $plugin_name The name of the plugin.
	 * @param      string $version     The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Allowed Html tags output
	 *
	 * @since    1.0.0
	 *
	 * @param string $plugin
	 *
	 * @return string
	 */
	public static function gdprct_get_allowed_html_tags_output( $plugin = '' ) {
		$allowedTags = self::gdprct_get_allowed_html_tags( $plugin );
		$output      = '<div class="wpgdprc-allowed-tags">';
		if ( ! empty( $allowedTags ) ) {
			$tags = '%privacy_policy%';
			foreach ( $allowedTags as $tag => $attributes ) {
				$tags .= ' <' . $tag;
				if ( ! empty( $attributes ) ) {
					foreach ( $attributes as $attribute => $data ) {
						$tags .= ' ' . $attribute . '=""';
					}
				}
				$tags .= '>';
			}
			$output .= sprintf(
				__( 'You can use: %s', 'gdpr-compliance-toolkit' ), sprintf( '<pre>%s</pre>', esc_html( $tags ) )
			);
		} else {
			$output .= sprintf(
				'<strong>%s:</strong> %s', strtoupper( __( 'Note', 'gdpr-compliance-toolkit' ) ), __( 'No HTML allowed due to plugin limitations.', 'gdpr-compliance-toolkit' )
			);
		}
		$output .= '</div>';

		return $output;
	}

	/**
	 * Allowed Html tags
	 *
	 * @since    1.0.0
	 *
	 * @param string $plugin
	 *
	 * @return mixed
	 */
	public static function gdprct_get_allowed_html_tags( $plugin = '' ) {
		switch ( $plugin ) {
			default :
				$output = array(
					'a'      => array(
						'class'    => array(),
						'href'     => array(),
						'hreflang' => array(),
						'title'    => array(),
						'target'   => array(),
						'rel'      => array(),
					),
					'br'     => array(),
					'em'     => array(),
					'strong' => array(),
					'u'      => array(),
					'strike' => array(),
					'span'   => array(
						'class' => array(),
					),
				);
				break;
		}

		return apply_filters( 'gdpr_allowed_html_tags', $output, $plugin );
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_Compliance_Toolkit_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_Compliance_Toolkit_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/gdpr-compliance-toolkit-public.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_Compliance_Toolkit_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_Compliance_Toolkit_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/gdpr-compliance-toolkit-public.js', array( 'jquery' ), $this->version, false );
	}

	/**
	 * Override woocommerce template
	 *
	 * @since    1.0.0
	 */
	public function gdprct_locate_template_conditions( $template, $template_name, $template_path ) {

		global $woocommerce;
		$_template = $template;

		if ( ! $template_path ) {
			$template_path = $woocommerce->template_url;
		}

		$plugin_path = gdpr_compliance_toolkit_plugin_path() . '/woocommerce/';
		$template    = locate_template(
			array(
				$template_path . $template_name,
				$template_name,
			)
		);

		// Modification: Get the template from this plugin, if it exists
		if ( ! $template && file_exists( $plugin_path . $template_name ) ) {
			$template = $plugin_path . $template_name;
		}

		// Use default template
		if ( ! $template ) {
			$template = $_template;
		}

		// Return what we found
		return $template;
	}

	/**
	 * Add WP GDPR field before submit button
	 *
	 * @since    1.0.0
	 */
	public function gdprct_add_field() {
		$args = array(
			'type'     => 'checkbox',
			'class'    => array( 'gdpr-checkbox' ),
			'label'    => self::gdprct_get_checkbox_text( 'woocommerce' ),
			'required' => true,
		);
		woocommerce_form_field( 'gdpr', apply_filters( 'gdpr_woocommerce_field_args', $args ) );
	}

	/**
	 * Get checkbox text
	 *
	 * @since    1.0.0
	 *
	 * @param string $plugin
	 *
	 * @param bool   $insertPrivacyPolicyLink
	 *
	 * @return string
	 */
	public static function gdprct_get_checkbox_text( $plugin = '', $insertPrivacyPolicyLink = true ) {
		$output                       = '';
		$get_gdpr_compilation_toolkit = json_decode( get_option( 'gdpr_compilation_toolkit' ) );

		if ( isset( $get_gdpr_compilation_toolkit->woo_integration->chk_text ) && ! empty( $get_gdpr_compilation_toolkit->woo_integration->chk_text ) ) {
			$woo_integration_chk_txt = $get_gdpr_compilation_toolkit->woo_integration->chk_text;
		}
		if ( isset( $get_gdpr_compilation_toolkit->woo_integration->err_msg ) && ! empty( $get_gdpr_compilation_toolkit->woo_integration->err_msg ) ) {
			$woo_integration_err_msg = $get_gdpr_compilation_toolkit->woo_integration->err_msg;
		}
		if ( ! empty( $plugin ) ) {
			$output = get_option( 'gdpr_integrations_' . $plugin . '_text' );
			$output = ( true === $insertPrivacyPolicyLink ) ? self::gdprct_insert_privacy_policy_link( $output ) : $output;
			$output = apply_filters( 'gdpr_' . $plugin . '_checkbox_text', $output );
		}
		if ( empty( $output ) ) {
			$output = __( $woo_integration_chk_txt, 'gdpr-compliance-toolkit' );
		}
		$output = wp_kses( $output, self::gdprct_get_allowed_html_tags( $plugin ) );

		return apply_filters( 'gdpr_checkbox_text', $output );
	}

	/**
	 * Insert link for privacy policy
	 *
	 * @since    1.0.0
	 *
	 * @param string $content
	 *
	 * @return mixed|string
	 *
	 */
	public static function gdprct_insert_privacy_policy_link( $content = '' ) {
		$page = get_option( 'gdpr_settings_privacy_policy_page' );
		$text = self::gdprct_get_privacy_policy_text();
		if ( ! empty( $page ) && ! empty( $text ) ) {
			$link    = apply_filters(
				'gdpr_privacy_policy_link', sprintf(
				'<a target="_blank" href="%s">%s</a>', get_page_link( $page ), esc_html( $text )
			), $page, $text
			);
			$content = str_replace( '%privacy_policy%', $link, $content );
		}

		return $content;
	}

	/**
	 * Get privacy policy text
	 *
	 * @since    1.0.0
	 *
	 * @return mixed
	 */
	public static function gdprct_get_privacy_policy_text() {
		$output = get_option( 'gdpr_settings_privacy_policy_text' );
		if ( empty( $output ) ) {
			$output = __( 'Privacy Policy', 'gdpr-compliance-toolkit' );
		}

		return apply_filters( 'gdpr_privacy_policy_text', $output );
	}

	/**
	 * Display error message.
	 *
	 * @since    1.0.0
	 *
	 * @return mixed|string
	 *
	 */
	public function gdprct_check_post() {
		if ( ! isset( $_POST['gdpr'] ) ) {
			wc_add_notice( self::gdprct_get_error_message( 'woocommerce' ), 'error' );
		}
	}

	/**
	 * Get error message
	 *
	 * @since    1.0.0
	 *
	 * @param string $plugin
	 *
	 * @return mixed
	 */
	public static function gdprct_get_error_message( $plugin = '' ) {
		$output                       = '';
		$get_gdpr_compilation_toolkit = json_decode( get_option( 'gdpr_compilation_toolkit' ) );

		if ( isset( $get_gdpr_compilation_toolkit->woo_integration->err_msg ) ) {
			$woo_integration_err_msg = $get_gdpr_compilation_toolkit->woo_integration->err_msg;
		}
		if ( ! empty( $plugin ) ) {
			$output = get_option( 'gdpr_integrations_' . $plugin . '_error_message' );
			$output = apply_filters( 'gdpr_' . $plugin . '_error_message', $output );
		}
		if ( empty( $output ) ) {
			$output = __( $woo_integration_err_msg, 'gdpr-compliance-toolkit' );
		}

		return apply_filters( 'gdpr_error_message', wp_kses( $output, self::gdprct_get_allowed_html_tags( $plugin ) ) );
	}

	/**
	 * Add GDPR in order (Update meta with gdpr)
	 *
	 * @since    1.0.0
	 *
	 * @param int $orderId
	 */
	public function gdprct_add_accepted_date_to_order_meta( $orderId = 0 ) {
		if ( isset( $_POST['gdpr'] ) && ! empty( $orderId ) ) {
			update_post_meta( $orderId, '_gdpr', time() );
		}
	}

	/**
	 * Display date for accepted GDPR date in order.
	 *
	 * @since    1.0.0
	 *
	 * @param \WC_Order $order
	 */
	public function gdprct_display_accepted_date_in_order_meta( $order ) {
		$label = __( 'GDPR accepted on:', 'gdpr-compliance-toolkit' );
		$date  = get_post_meta( $order->get_id(), '_gdpr', true );
		$value = ( ! empty( $date ) ) ? self::gdprct_local_date_format( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), $date ) : __( 'Not accepted.', 'gdpr-compliance-toolkit' );
		echo apply_filters(
			'gdpr_woocommerce_accepted_date_in_order_data', sprintf( '<p class="form-field form-field-wide gdpr-accepted-date"><strong>%s</strong><br />%s</p>', $label, $value ), $label, $value, $order
		);
	}

	/**
	 * Date format
	 *
	 * @since    1.0.0
	 *
	 * @param string $format
	 *
	 * @param int    $timestamp
	 *
	 * @return string
	 */
	public static function gdprct_local_date_format( $format = '', $timestamp = 0 ) {
		$gmtOffset = get_option( 'gmt_offset', '' );
		if ( $gmtOffset !== '' ) {
			$negative  = ( $gmtOffset < 0 );
			$gmtOffset = str_replace( '-', '', $gmtOffset );
			$hour      = floor( $gmtOffset );
			$minutes   = ( $gmtOffset - $hour ) * 60;
			if ( $negative ) {
				$hour    = '-' . $hour;
				$minutes = '-' . $minutes;
			}
			$date = new \DateTime( null, new \DateTimeZone( 'UTC' ) );
			$date->setTimestamp( $timestamp );
			$date->modify( $hour . ' hour' );
			$date->modify( $minutes . ' minutes' );
		} else {
			$date = new \DateTime( null, new \DateTimeZone( get_option( 'timezone_string', 'UTC' ) ) );
			$date->setTimestamp( $timestamp );
		}
		$date = new \DateTime( $date->format( 'Y-m-d H:i:s' ), new \DateTimeZone( 'UTC' ) );

		return date_i18n( $format, $date->getTimestamp(), true );
	}

	/**
	 * Add new endpoint in myaccount page
	 *
	 * @since  1.0
	 *
	 */
	public function gdprct_add_custom_my_gdpr_data_endpoint() {
		add_rewrite_endpoint( 'my-gdpr-data', EP_ROOT | EP_PAGES );
		flush_rewrite_rules();
	}

	/**
	 * Add new query var.
	 *
	 * @since  1.0
	 *
	 * @param array $vars
	 *
	 * @return array
	 *
	 */
	public function gdprct_my_gdpr_data_query_vars( $vars ) {
		$vars[] = 'my-gdpr-data';

		return $vars;
	}

	/**
	 * Insert the new endpoint into the My Account menu.
	 *
	 * @since  1.0
	 *
	 * @param array $items
	 *
	 * @return array
	 *
	 */
	public function gdprct_add_my_gdpr_data_link_my_account( $items ) {
		$logout = $items['customer-logout'];
		unset( $items['customer-logout'] );
		$items['my-gdpr-data']    = esc_html__( 'My GDPR Data', 'shopstudio' );
		$items['customer-logout'] = $logout;

		return $items;
	}

	/**
	 * Endpoint HTML content.
	 *
	 * @since  1.0
	 *
	 */
	public function gdprct_my_gdpr_data_content() {
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'woocommerce/myaccount/my-gdpr-data.php';
	}
}